==> haskell-lambdabot-trusted-5.3.1.2-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-3bFwJMG4G2tAMKzXzrlmlm
key:                  lambdabot-trusted-5.3.1.2-3bFwJMG4G2tAMKzXzrlmlm
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  f0313a0508fb147a78ff176e5ad6093e
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-3bFwJMG4G2tAMKzXzrlmlm
depends:
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF
    QuickCheck-safe-0.1.0.6-2b765ML6hoX4037dZVw8hd base-4.17.2.1
    oeis-0.3.10.1-CdCSkdQ8wVkDfYOA5op6he

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lambdabot-trusted-5.3.1.2-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-RORwqjKjRH42Bk8hYuJtI
key:                  lambdabot-trusted-5.3.1.2-RORwqjKjRH42Bk8hYuJtI
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  0fc8b7c9ddc8056137dfc6e76bb0b4d1
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-RORwqjKjRH42Bk8hYuJtI
depends:
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF
    QuickCheck-safe-0.1.0.6-2b765ML6hoX4037dZVw8hd base-4.17.2.1
    oeis-0.3.10.1-5eTEpjr7LaP5OgcmRuJj1P

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
